################################################################################
# R Code related to                                                            #
# Drought effects on hay and feed grain prices                                 #
# Sergei Schaub and Robert Finger                                              #  
# -----------------------------------------------------------------------------#
# Data preparation, estimation and visualization r script                      #
#  2019, ETH Zurich                                                           #
# developed by Sergei Schaub                                                   #  
################################################################################


# table of content:
# 0. general settings
# 1. preparation of feed price data and drought information
# 1.1. feed price data
# 1.2. drought information
# 1.3. merging and processing of feed price data and drought information
# 2. data attributes
# 2.1. summary statistics of feed price data
# 2.2. testing for optimal lag length and augmented Dickey Fuller test (ADF) unit root test
# 3. SVAR Estimation
# 4. data and results visualization
# 4.1. visualization of feed price data
# 4.2. visualization of drought information
# 4.3. visualization of impulse response functions
# 4.4. visualization of spei information


################################################################################
#--------------------- 0. general settings
################################################################################


# load packages
require(tidyverse)
require(tseries)
require(lmtest)
require(vars)
require(ggpubr)


# define working directories:
cd_input_data <- cd_input_data # working directory of data (except spei data)
cd_processed  <- cd_processed  # working directory of spei data
cd_results    <- cd_results    # working directory where results should be saved
cd_figures    <- cd_figures    # working directory where figures should be saved



################################################################################
#--------------------- 1. preparation of feed price data and drought information
################################################################################

#-------------------------------------------------------------------------------------------------
# 1.1. feed price data ###
#-------------------------------------------------------------------------------------------------  

# load feed price data:
setwd(cd_input_data)
p1 <-read_csv("monthly_feed_prices.csv") 


# add date variable and convert year into character (later needed)
p1 <- p1 %>% mutate(date = as.Date(as.character(paste(month,"15",year, sep = "/" )), format =  "%m/%d/%Y" ),
                    year = as.character(year)) 


# load harmonized index of consumer prices (hicp) for germany (source EUROSTAT) and prepare data for matching with price data
h1 <- read.csv("HICP_germany.csv", header=T,sep=";") %>% 
    mutate(hicp  = as.numeric(hicp),
           year  = as.character(year),
           month = ifelse(month>9,as.character(month),as.character(paste0(0,month))))

# add hicp to price data and compute real prices (_r) and natural log transformed real prices (_r_ln)
p1 <- p1 %>% left_join(h1, by =c("year","month")) %>%  
             mutate(hay_r       = hay_m/(hicp/100), 
                    wheat_r     = wheat_m/(hicp/100),
                    barley_r    = barley_m/(hicp/100),
                    hay_r_ln    = log(hay_r),   
                    wheat_r_ln  = log(wheat_r),
                    barley_r_ln = log(barley_r)) %>% ungroup() 

# create additional dataset (used later for visualization)
p1_plotting <- p1 %>% gather('hay_r','hay_r_ln','wheat_r','wheat_r_ln','barley_r','barley_r_ln',
                             key = "object",value = "price")


#-------------------------------------------------------------------------------------------------
# 1.2. drought information ###
#-------------------------------------------------------------------------------------------------  

# load spei data:
setwd(cd_processed)
w1 <-read_csv("spei_data_SG_DE.csv")


# rearrange variables:
w1 <- w1 %>% dplyr::select(c(year, month, mean_spei_3_sg,mean_spei_2_sg,mean_spei_4_sg,mean_spei_3_de,mean_spei_2_de,mean_spei_4_de))

# set main vegetation period (start: staveg+1, end: endveg-1):
staveg <- 3
endveg <- 11

# set summer and spring period 
summer_s = 6 # summer start = spring end = june
summer_e = 8 # summer end = august


# create matrix with different drought thresholds: 
cuts <- as.data.frame(matrix(c("cut_1.0","cut_1.5", -1.0,-1.5), nrow = 2, ncol = 2, byrow = F))
cuts <- cuts %>%  mutate(V2 = as.numeric(as.character(V2)))


#-------------------------------------------------------------------------------------------------
# Remark: In the next loops the drought variables are defined for the different drought specifications 
#-------------------------------------------------------------------------------------------------  

n4_ <- length(cuts$V1) # number of runs of the next loops

for(g in 1:n4_) { # for spei-3 and south germany
  
w1 <- w1 %>% mutate(
drought_y   = ifelse(mean_spei_3_sg<=cuts[g,2],(mean_spei_3_sg)*(-1),0),
drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
drought_spr = ifelse(mean_spei_3_sg<=cuts[g,2],(mean_spei_3_sg)*(-1),0),
drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
drought_sum = ifelse(mean_spei_3_sg<=cuts[g,2],(mean_spei_3_sg)*(-1),0),
drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
)

# rename
colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_y_sd")
colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_spr_sd")
colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_sum_sd")

}

for(g in 1:n4_) { # for spei-2 and south germany
  
  w1 <- w1 %>% mutate(
    drought_y   = ifelse(mean_spei_2_sg<=cuts[g,2],(mean_spei_2_sg)*(-1),0),
    drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
    drought_spr = ifelse(mean_spei_2_sg<=cuts[g,2],(mean_spei_2_sg)*(-1),0),
    drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
    drought_sum = ifelse(mean_spei_2_sg<=cuts[g,2],(mean_spei_2_sg)*(-1),0),
    drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
  )
  
  # rename
  colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_y_sd")
  colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_spr_sd")
  colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_sum_sd")
  
}

for(g in 1:n4_) { # for spei-4 and south germany
  
  w1 <- w1 %>% mutate(
    drought_y   = ifelse(mean_spei_4_sg<=cuts[g,2],(mean_spei_4_sg)*(-1),0),
    drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
    drought_spr = ifelse(mean_spei_4_sg<=cuts[g,2],(mean_spei_4_sg)*(-1),0),
    drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
    drought_sum = ifelse(mean_spei_4_sg<=cuts[g,2],(mean_spei_4_sg)*(-1),0),
    drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
  )
  
  # rename
  colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_y_sd")
  colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_spr_sd")
  colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_sum_sd")
  
}


for(g in 1:n4_) { # for spei-3 and germany
  
  w1 <- w1 %>% mutate(
    drought_y   = ifelse(mean_spei_3_de<=cuts[g,2],(mean_spei_3_de)*(-1),0),
    drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
    drought_spr = ifelse(mean_spei_3_de<=cuts[g,2],(mean_spei_3_de)*(-1),0),
    drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
    drought_sum = ifelse(mean_spei_3_de<=cuts[g,2],(mean_spei_3_de)*(-1),0),
    drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
  )
  
  # rename
  colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_y_de")
  colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_spr_de")
  colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei3_sum_de")
  
}


for(g in 1:n4_) { # for spei-2 and germany
  
  w1 <- w1 %>% mutate(
    drought_y   = ifelse(mean_spei_2_de<=cuts[g,2],(mean_spei_2_de)*(-1),0),
    drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
    drought_spr = ifelse(mean_spei_2_de<=cuts[g,2],(mean_spei_2_de)*(-1),0),
    drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
    drought_sum = ifelse(mean_spei_2_de<=cuts[g,2],(mean_spei_2_de)*(-1),0),
    drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
  )
  
  # rename
  colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_y_de")
  colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_spr_de")
  colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei2_sum_de")
  
}


for(g in 1:n4_) { # for spei-4 and germany
  
  w1 <- w1 %>% mutate(
    drought_y   = ifelse(mean_spei_4_de<=cuts[g,2],(mean_spei_4_de)*(-1),0),
    drought_y   = ifelse(endveg>month & month>staveg,drought_y,0),  # only consider main vegetation period period
    drought_spr = ifelse(mean_spei_4_de<=cuts[g,2],(mean_spei_4_de)*(-1),0),
    drought_spr = ifelse(summer_s>month & month>staveg,drought_spr,0),  # only consider main vegetation period period & spring months
    drought_sum = ifelse(mean_spei_4_de<=cuts[g,2],(mean_spei_4_de)*(-1),0),
    drought_sum = ifelse(summer_e>=month & month>=summer_s,drought_sum,0)  # only consider main vegetation period period & summer months
  )
  
  # rename
  colnames(w1)[(length(w1)-2)] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_y_de")
  colnames(w1)[(length(w1)-1)] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_spr_de")
  colnames(w1)[(length(w1))] <-  paste0("drought_",paste(cuts[g,2]),"_spei4_sum_de")
  
}


# add year, month and date
w1 <- w1 %>% mutate(month = ifelse(month>9,as.character(month),as.character(paste0(0,month))),
                    year  = as.character(year),
                    date = as.Date(as.character(paste(month,"15",year,sep = "/")),format =  "%m/%d/%Y"))

# reduce weather data to only period of time series and to variables needed 
n_months <- length(w1$year) # number of months
w1 <- w1 %>% mutate(time = c(1:n_months)) %>% filter(time>=140 & time<=n_months)  # from agust 2002 to april 2019 
w2 <- w1 %>% dplyr::select(c(year,month,c(mean_spei_4_de:date)))%>% dplyr::select(-mean_spei_4_de)


# create additional dataset (used later for visualization)
## subset to plot droughts based on spei-3 for south germany and germany
w2_plot_spei3 <- w2 %>% gather('drought_-1_spei3_y_sd','drought_-1_spei3_spr_sd','drought_-1_spei3_sum_sd',
                             'drought_-1.5_spei3_y_sd','drought_-1.5_spei3_spr_sd','drought_-1.5_spei3_sum_sd',
                             'drought_-1_spei3_y_de','drought_-1_spei3_spr_de','drought_-1_spei3_sum_de',
                             'drought_-1.5_spei3_y_de','drought_-1.5_spei3_spr_de','drought_-1.5_spei3_sum_de',
                             key = "object",value = "drought_v") %>% mutate(aux1 = substr(object, start = 9, stop = 11),
                                                                            aux1 = ifelse(aux1=="-1.","1.5",
                                                                                          ifelse(aux1=="-1_","1.0",NA)),
                                                                            aux2 = str_sub(object, -6,-4),
                                                                            aux3 = ifelse(aux2=="spr",
                                                                                          paste0("Spring drought, threshold: -",aux1),
                                                                                          ifelse(aux2=="sum",
                                                                                                 paste0("Summer drought, threshold: -",aux1),
                                                                                                 paste0("All drought, threshold: -",aux1))))

## subset to plot droughts based on spei-2 for south germany and germany
w2_plot_spei2 <- w2 %>% gather('drought_-1_spei2_y_sd','drought_-1_spei2_spr_sd','drought_-1_spei2_sum_sd',
                               'drought_-1.5_spei2_y_sd','drought_-1.5_spei2_spr_sd','drought_-1.5_spei2_sum_sd',
                               'drought_-1_spei2_y_de','drought_-1_spei2_spr_de','drought_-1_spei2_sum_de',
                               'drought_-1.5_spei2_y_de','drought_-1.5_spei2_spr_de','drought_-1.5_spei2_sum_de',
                               key = "object",value = "drought_v") %>% mutate(aux1 = substr(object, start = 9, stop = 11),
                                                                              aux1 = ifelse(aux1=="-1.","1.5",
                                                                                            ifelse(aux1=="-1_","1.0",NA)),
                                                                              aux2 = str_sub(object, -6,-4),
                                                                              aux3 = ifelse(aux2=="spr",
                                                                                            paste0("Spring drought, threshold: -",aux1),
                                                                                            ifelse(aux2=="sum",
                                                                                                   paste0("Summer drought, threshold: -",aux1),
                                                                                                   paste0("All drought, threshold: -",aux1))))



## subset to plot droughts based on spei-4 for south germany and germany
w2_plot_spei4 <- w2 %>% gather('drought_-1_spei4_y_sd','drought_-1_spei4_spr_sd','drought_-1_spei4_sum_sd',
                               'drought_-1.5_spei4_y_sd','drought_-1.5_spei4_spr_sd','drought_-1.5_spei4_sum_sd',
                               'drought_-1_spei4_y_de','drought_-1_spei4_spr_de','drought_-1_spei4_sum_de',
                               'drought_-1.5_spei4_y_de','drought_-1.5_spei4_spr_de','drought_-1.5_spei4_sum_de',
                               key = "object",value = "drought_v") %>% mutate(aux1 = substr(object, start = 9, stop = 11),
                                                                              aux1 = ifelse(aux1=="-1.","1.5",
                                                                                            ifelse(aux1=="-1_","1.0",NA)),
                                                                              aux2 = str_sub(object, -6,-4),
                                                                              aux3 = ifelse(aux2=="spr",
                                                                                            paste0("Spring drought, threshold: -",aux1),
                                                                                            ifelse(aux2=="sum",
                                                                                                   paste0("Summer drought, threshold: -",aux1),
                                                                                                   paste0("All drought, threshold: -",aux1))))


# delete date variable from drought dataset
w2 <- w2 %>% dplyr::select(-date) 


#-------------------------------------------------------------------------------------------------
# 1.3. merging and processing of feed price data and drought information ###
#-------------------------------------------------------------------------------------------------  

p1 <- p1 %>% left_join(w2, by = c("year","month"))


################################################################################
#--------------------- 2. data attributes
################################################################################

#-------------------------------------------------------------------------------------------------
# 2.1. summary statistics of feed price data ###
#-------------------------------------------------------------------------------------------------  

# hay prices
mean(p1$hay_r)
mean(p1$hay_r_ln)
median(p1$hay_r)
median(p1$hay_r_ln)
sd(p1$hay_r)
sd(p1$hay_r_ln)

# feed wheat prices
mean(p1$wheat_r)
mean(p1$wheat_r_ln)
median(p1$wheat_r)
median(p1$wheat_r_ln)
sd(p1$wheat_r)
sd(p1$wheat_r_ln)

# feed barley prices
mean(p1$barley_r)
mean(p1$barley_r_ln)
median(p1$barley_r)
median(p1$barley_r_ln)
sd(p1$barley_r)
sd(p1$barley_r_ln)


#-------------------------------------------------------------------------------------------------
# 2.2. testing for optimal lag length and Augmented Dickey Fuller (ADF) unit root test ###
#-------------------------------------------------------------------------------------------------  

# note that in the considered time no severe (threshold=-1.5) spring drought based on spei-4 occurred in germany. Therefore, this variable is deleted
p2 <- p1 %>% dplyr::select(-c("drought_-1.5_spei4_spr_de"))


# select a subset of the data. Note that we only show here the ADF test for one drought variable
p1ts <- p2 %>% dplyr::select("drought_-1_spei3_y_sd",wheat_r_ln,barley_r_ln,hay_r_ln) 
colnames(p1ts) <- c("drought","wheat","barley","hay") # rename variables
p1ts <- p1ts %>%  ts() # transform dataset into time series

# testing for optimal lag length (d*) based on feed prices
AIC <- VARselect(p1ts[,2:4],lag.max = 24, type = "const")
AIC$selection[1] # d*

# ADF test:
adf_hay <- summary(ur.df(p1ts[,"hay"],type = "drift",lags = 3))
adf_hay
adf_wheat <- summary(ur.df(p1ts[,"wheat"],type = "drift",lags = 3))
adf_wheat
adf_barley <- summary(ur.df(p1ts[,"barley"],type = "drift",lags = 3))
adf_barley
adf_d <- summary(ur.df(p1ts[,"drought"],type = "none",lags = 3))
adf_d



################################################################################
#--------------------- 3. SVAR Estimation
################################################################################

# note that we use a loop for '3. SVAR Estimation'

# number of runs of the first loop = number of different confidence intervals
ci_levels <- c(0.95,0.90,0.99) # define different confidence intervals 
nci_ <- length(ci_levels)

# number of runs of the second loop = number of drought specifications
n5_ <- length(p2 %>% dplyr::select(c("drought_-1_spei3_y_sd":"drought_-1.5_spei4_sum_de")))

# model restriction:
amat <- diag(4)
amat[2, 1] <- NA ;amat[3, 1] <- NA;  amat[4, 1] <- NA; amat[3, 2] <- NA ;amat[4, 2] <- NA;  amat[4, 3] <- NA
show(amat)


for(q in 1:nci_) { # loop over different confidence intervals  
  
  ci_level <- ci_levels[q] # current confidence interval 
  
  for(g in 1:n5_) { # loop over different drought specifications  
  
    
    #-------------------------------------------------------------------------------------------------
    # 3.1. estimation of SVAR and storing of results ###
    #------------------------------------------------------------------------------------------------- 
    
    drought_value_name <- colnames(p2)[13+g]  # current drought specification
    print(paste0("CI(",q,"/",nci_,"): drought specification: ",drought_value_name," (",g,"/",n5_,")")) # show progress of current loop, i.e. current confidence interval and drought specifications   
    
    p1ts  <- p2 %>% dplyr::select(paste(drought_value_name),wheat_r_ln,barley_r_ln,hay_r_ln) # select variables for SVAR
    colnames(p1ts) <- c("drought","wheat","barley","hay") # rename variables 
    p1ts <- p1ts %>% ts() # transform dataset into time series
    
    
    # estimate VAR model
    var <- VAR(p1ts, p = 3, type = "const")
    
    # estimate SVAR model
    svar <- SVAR(var, estmethod = "direct", Amat = amat, method="BFGS")
    
    # impulse response function (IRF):
    irf_hay <- irf(svar, impulse = "drought", response = "hay", n.ahead = 50, ortho = TRUE, 
                   cumulative = FALSE, boot = TRUE, ci = ci_level, runs = 2000, seed = 3,
                   max.iter = 1000, maxls = 1000, con.crit = 1.0e-4) 
    
    irf_wheat <- irf(svar, impulse = "drought", response = "wheat", n.ahead = 50, ortho = TRUE, 
                     cumulative = FALSE, boot = TRUE, ci = ci_level, runs = 2000, seed = 3,
                     max.iter = 1000, maxls = 1000, con.crit = 1.0e-4) 
    
    irf_barley <- irf(svar, impulse = "drought", response = "barley", n.ahead = 50, ortho = TRUE, 
                      cumulative = FALSE, boot = TRUE, ci = ci_level, runs = 2000, seed = 3,
                      max.iter = 1000, maxls = 1000, con.crit = 1.0e-4) 
    
    
    # store data of IRFs of:
    ## hay prices
    irf_d1_hay_de <- data.frame(irf_hay$irf$drought)
    irf_d1_hay_de$CIlower <- (irf_hay$Lower$drought)
    irf_d1_hay_de$CIupper <- (irf_hay$Upper$drought)
    irf_d1_hay_de$months  <- as.integer(seq(1:length(irf_d1_hay_de$CIlower)))
    irf_d1_hay_de$drougt_spec <- drought_value_name
    
    if (g==1) { # for the first loop of g create new dataset
      dat_irf_hay <- irf_d1_hay_de}
    
    if (g>1)  { # for all other loops of g add to existing dataset
      dat_irf_hay <- bind_rows(dat_irf_hay,irf_d1_hay_de) }  
    
    
    ## feed wheat prices
    irf_d1_wheat_de <- data.frame(irf_wheat$irf$drought)
    irf_d1_wheat_de$CIlower <- (irf_wheat$Lower$drought)
    irf_d1_wheat_de$CIupper <- (irf_wheat$Upper$drought)
    irf_d1_wheat_de$months <- as.integer(seq(1:length(irf_d1_wheat_de$CIlower)))
    irf_d1_wheat_de$drougt_spec <- drought_value_name
    
    if (g==1) { # for the first loop of g create new dataset
      dat_irf_wheat <- irf_d1_wheat_de}
    
    if (g>1)  { # for all other loops of g add to existing dataset
      dat_irf_wheat <- bind_rows(dat_irf_wheat,irf_d1_wheat_de) }  
    
    
    ## feed barley prices
    irf_d1_barley_de <- data.frame(irf_barley$irf$drought)
    irf_d1_barley_de$CIlower <- (irf_barley$Lower$drought)
    irf_d1_barley_de$CIupper <- (irf_barley$Upper$drought)
    irf_d1_barley_de$months <- as.integer(seq(1:length(irf_d1_barley_de$CIlower)))
    irf_d1_barley_de$drougt_spec <- drought_value_name
    
    if (g==1) { # for the first loop of g create new dataset
      dat_irf_barley <- irf_d1_barley_de}
    
    if (g>1)  { # for all other loops of g add to existing dataset
      dat_irf_barley <- bind_rows(dat_irf_barley,irf_d1_barley_de) }  
  } # end of loop over drought specifications
  
  
  #-------------------------------------------------------------------------------------------------
  # 3.2. preparation of results for table 2 ###
  #------------------------------------------------------------------------------------------------- 

  # prepare results
  ## hay prices
  dat_irf_hay_3 <- dat_irf_hay %>% mutate(swap = ifelse(CIlower*CIupper>0,hay,0),
                                          month_positive = ifelse(swap>0,as.numeric(months),100)) %>% group_by(drougt_spec) %>% 
    mutate(peak.effect = max(swap),
           start.effect = min(month_positive),
           month_positive = ifelse(swap>0,as.numeric(months),0),
           end.effect = max(month_positive),
           result = ifelse(peak.effect>0, paste0(round(peak.effect,2)," (",start.effect,"-",end.effect,")"),"-"))
  
  dat_irf_hay_4 <- dat_irf_hay_3 %>% ungroup() %>% dplyr::select(drougt_spec,result) %>% distinct() %>% 
    mutate(location = ifelse(str_detect(drougt_spec, "_sd$"),"South Germany","Germany"),
           time = ifelse(str_detect(drougt_spec, "_y_"),"All",
                         ifelse(str_detect(drougt_spec, "_spr_"),"Spring","Summer")),
           spei = ifelse(str_detect(drougt_spec, "spei3"),"SPEI-3",
                         ifelse(str_detect(drougt_spec, "spei2"),"SPEI-2","SPEI-4")),
           threshold = ifelse(str_detect(drougt_spec, "-1.5"),"-1.5",
                              ifelse(str_detect(drougt_spec, "-1_"),"-1.0","-2.0")))
  
  ## feed wheat prices
  dat_irf_wheat_3 <- dat_irf_wheat %>% mutate(swap = ifelse(CIlower*CIupper>0,wheat,0),
                                              month_positive = ifelse(swap>0,as.numeric(months),100)) %>% group_by(drougt_spec) %>% 
    mutate(peak.effect = max(swap),
           start.effect = min(month_positive),
           month_positive = ifelse(swap>0,as.numeric(months),0),
           end.effect = max(month_positive),
           result = ifelse(peak.effect>0, paste0(round(peak.effect,2)," (",start.effect,"-",end.effect,")"),"-"))
  
  dat_irf_wheat_4 <- dat_irf_wheat_3 %>% ungroup() %>% dplyr::select(drougt_spec,result) %>% distinct() %>% 
    mutate(location = ifelse(str_detect(drougt_spec, "_sd$"),"South Germany","Germany"),
           time = ifelse(str_detect(drougt_spec, "_y_"),"All",
                         ifelse(str_detect(drougt_spec, "_spr_"),"Spring","Summer")),
           spei = ifelse(str_detect(drougt_spec, "spei3"),"SPEI-3",
                         ifelse(str_detect(drougt_spec, "spei2"),"SPEI-2","SPEI-4")),
           threshold = ifelse(str_detect(drougt_spec, "-1.5"),"-1.5",
                              ifelse(str_detect(drougt_spec, "-1_"),"-1.0","-2.0")))
  
  ## feed barley prices
  dat_irf_barley_3 <- dat_irf_barley %>% mutate(swap = ifelse(CIlower*CIupper>0,barley,0),
                                                month_positive = ifelse(swap>0,as.numeric(months),100)) %>% group_by(drougt_spec) %>% 
    mutate(peak.effect = max(swap),
           start.effect = min(month_positive),
           month_positive = ifelse(swap>0,as.numeric(months),0),
           end.effect = max(month_positive),
           result = ifelse(peak.effect>0, paste0(round(peak.effect,2)," (",start.effect,"-",end.effect,")"),"-"))
  
  dat_irf_barley_4 <- dat_irf_barley_3 %>% ungroup() %>% dplyr::select(drougt_spec,result) %>% distinct() %>% 
    mutate(location = ifelse(str_detect(drougt_spec, "_sd$"),"South Germany","Germany"),
           time = ifelse(str_detect(drougt_spec, "_y_"),"All",
                         ifelse(str_detect(drougt_spec, "_spr_"),"Spring","Summer")),
           spei = ifelse(str_detect(drougt_spec, "spei3"),"SPEI-3",
                         ifelse(str_detect(drougt_spec, "spei2"),"SPEI-2","SPEI-4")),
           threshold = ifelse(str_detect(drougt_spec, "-1.5"),"-1.5",
                              ifelse(str_detect(drougt_spec, "-1_"),"-1.0","-2.0")))
  
 
  # save results
  setwd(cd_results)
  ## create file names
  file_hay <- paste0("hay_irf_results_CI_",ci_level,".csv")   
  file_wheat <- paste0("wheat_irf_results_CI_",ci_level,".csv")  
  file_barley <- paste0("barley_irf_results_CI_",ci_level,".csv")  
  ## save
  write.csv(dat_irf_hay_4, file = file_hay)
  write.csv(dat_irf_wheat_4, file = file_wheat)
  write.csv(dat_irf_barley_4, file = file_barley)
  
  #-------------------------------------------------------------------------------------------------
  # 3.3. preparation of results for table 3 ###
  #------------------------------------------------------------------------------------------------- 

  # preparation of IRF results: 
  dat_irf_hay_2 <- dat_irf_hay %>% gather(key = "object",value = "value",-"months",-"drougt_spec") 
  dat_irf_wheat_2 <- dat_irf_wheat %>% gather(key = "object",value = "value",-"months",-"drougt_spec") 
  dat_irf_barley_2 <- dat_irf_barley %>% gather(key = "object",value = "value",-"months",-"drougt_spec") 
  
  # combine different IRF results
  dat_irf_all_2 <- bind_rows((dat_irf_hay_2 %>% mutate(y = "Hay")),
                             (dat_irf_wheat_2 %>% mutate(y = "Wheat")),
                             (dat_irf_barley_2 %>% mutate(y = "Barley"))) %>% 
    mutate(object2 = ifelse(str_detect(object, "hay")|str_detect(object, "wheat")|str_detect(object, "barley"),"price",object),
           location2 = ifelse(str_detect(drougt_spec, "_sd"),"South Germany","Germany"),
           aux2 = paste(y,"price in", location2))
  
  dat_irf_all_2$aux2 <- factor(dat_irf_all_2$aux2, levels = c("Hay price in South Germany","Hay price in Germany",
                                                              "Wheat price in South Germany", "Wheat price in Germany",
                                                              "Barley price in South Germany", "Barley price in Germany"))
  
  # add information about current confidence intervals
  dat_irf_all_2 <- dat_irf_all_2 %>% mutate(ci_level_ = ci_level)
  
  # if the first run over confidence intervals create new data frame
  if(q == 1) {dat_irf_all_3 <-  dat_irf_all_2} else {
    dat_irf_all_3 <- bind_rows(dat_irf_all_3, (dat_irf_all_2 %>% filter(!object2=="price"))) } # we only want to add other confidence intervals. 
  
} # end of loop over confidence intervals

# save results
# setwd(cd_processed)
# write.csv(dat_irf_all_3, file = "figure_3_results_CI_all.csv")


################################################################################
#--------------------- 4. data and results visualization
################################################################################

#-------------------------------------------------------------------------------------------------
# 4.1. visualization of feed price data (Figure 1) ###
#------------------------------------------------------------------------------------------------- 

p1_plotting_aux <- p1_plotting %>% filter(str_detect(object, "_r_ln$")) # only plot natural log transformed real prices
p1_plotting_aux$object <- factor(p1_plotting_aux$object, levels = c("hay_r_ln","wheat_r_ln","barley_r_ln"))

plot_1 <- p1_plotting_aux %>%  
  ggplot(aes(date,price,colour=object))+
  geom_line(size=1.)+
  geom_hline(yintercept = c(0))+
  labs(y = "(ln) Price in Euro 100"~kg^{-1}, 
       x = "Date")+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 14),legend.position=c(.85, .15),legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=18),
        axis.title=element_text(size=20),
        legend.text=element_text(size=18))+
  scale_x_date(date_labels = "%Y",date_breaks = "2 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))+
  scale_colour_manual(values = c("#e41a1c","#377eb8","#4daf4a"),labels =c("Hay price","Feed wheat price","Feed barley price"))

plot_1

# save figure
setwd(cd_figures)
ggsave("prices_real_ln.pdf",plot=plot_1 , width = 11, height = 8.5) 


#-------------------------------------------------------------------------------------------------
# 4.2. visualization of drought information (Figure 2, A2,A3, A4, A5, A6, A7) ###
#------------------------------------------------------------------------------------------------- 

# plot droughts (based on spei-3) in south germany and whole germany for the threshold -1.5
plot_2 <- w2_plot_spei3 %>% filter(aux1==1.5)  %>% 
          mutate(aux4 = str_sub(object,start = -2, end = -1),
                 aux4 = ifelse(aux4 == "sd","South Germany","Whole Germany"),
                 aux5 = paste(aux4,aux3),  
                 aux5 = factor(aux5, levels = c("South Germany All drought, threshold: -1.5","Whole Germany All drought, threshold: -1.5",
                                                "South Germany Spring drought, threshold: -1.5","Whole Germany Spring drought, threshold: -1.5",
                                                "South Germany Summer drought, threshold: -1.5","Whole Germany Summer drought, threshold: -1.5"))) %>% 
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux5, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "Severe droughts, SPEI-3")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_2



# plot droughts (based on spei-3) in south germany
plot_3 <- w2_plot_spei3 %>% filter(str_detect(object, "_sd$")) %>%  
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "South Germany, SPEI-3")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_3

# plot droughts (based on spei-3) in germany
plot_4 <- w2_plot_spei3 %>% filter(str_detect(object, "_de$")) %>%  
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "Germany, SPEI-3")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_4


# plot droughts (based on spei-2) in south germany
plot_5 <- w2_plot_spei2 %>% filter(str_detect(object, "_sd$")) %>% 
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "South Germany, SPEI-2")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_5

# plot droughts (based on spei-2) in germany
plot_6 <- w2_plot_spei2 %>% filter(str_detect(object, "_de$")) %>%
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "Germany, SPEI-2")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_6


# plot droughts (based on spei-4) in south germany
plot_7 <- w2_plot_spei4 %>% filter(str_detect(object, "_sd$")) %>% 
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "South Germany, SPEI-4")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_7

# plot droughts (based on spei-4) in germany
plot_8 <- w2_plot_spei4 %>% filter(str_detect(object, "_de$")) %>%  
  ggplot()+
  geom_bar( 
    aes(date, drought_v ,fill = factor(aux2)),stat="identity", na.rm = T )+
  facet_wrap( ~ aux3, nrow=3)+
  geom_hline(yintercept = c(0))+
  labs(y = "Droughts", 
       x = "Date",
       title = "Germany, SPEI-4")+ 
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 16),legend.position="none",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=14),
        axis.title=element_text(size=16))+
  scale_x_date(date_labels = "%Y",date_breaks = "3 year",limits=c(as.Date("2002-08-01"), as.Date("2019-05-30")))

plot_8

# save figures
setwd(cd_figures)
ggsave("spei3_south_germamy_and_germany_figure2.pdf",plot=plot_2 , width = 7.5, height =  8.5) 
ggsave("spei3_south_germamy_figureA2.pdf",plot=plot_3 , width = 7.5, height =  8.5) 
ggsave("spei3_germamy_figureA3.pdf",plot=plot_4 , width = 7.5, height =  8.5) 
ggsave("spei2_south_germamy_figureA4.pdf",plot=plot_5 , width = 7.5, height =  8.5) 
ggsave("spei2_germamy_figureA5.pdf",plot=plot_6 , width = 7.5, height =  8.5) 
ggsave("spei4_south_germamy_figureA6.pdf",plot=plot_7 , width = 7.5, height =  8.5) 
ggsave("spei4_germamy_figureA7.pdf",plot=plot_8 , width = 7.5, height =  8.5) 


#-------------------------------------------------------------------------------------------------
# 4.3. visualization of impulse response functions (Figure 3) ###
#-------------------------------------------------------------------------------------------------  


## data preperation
dat_irf_all_3_lines <- dat_irf_all_3 %>%  filter(str_detect(drougt_spec, "_y_"),
                                                 str_detect(drougt_spec, "_spei3_"),
                                                 str_detect(drougt_spec, "_-1.5_"),
                                                 object2=="price")

dat_irf_all_3_area_max <- dat_irf_all_3 %>%  filter(str_detect(drougt_spec, "_y_"),
                                                str_detect(drougt_spec, "_spei3_"), 
                                                str_detect(drougt_spec, "_-1.5_"),
                                                object2=="CIupper")
dat_irf_all_3_area_min <- dat_irf_all_3 %>%  filter(str_detect(drougt_spec, "_y_"),
                                                    str_detect(drougt_spec, "_spei3_"), 
                                                    str_detect(drougt_spec, "_-1.5_"),
                                                    object2=="CIlower")
dat_irf_all_3_area <- bind_cols(dat_irf_all_3_area_max, (dat_irf_all_3_area_min %>% dplyr::select(value))) %>% 
  mutate(object3 = paste( ifelse(object2=="CIupper","CI",NA),ci_level_))

dat_irf_all_3_area$object3 <- factor(dat_irf_all_3_area$object3, levels = c("CI 0.99","CI 0.95","CI 0.9"  ))


## plot IRFs: 
plot_9 <- ggplot( )+
  geom_ribbon(data = dat_irf_all_3_area, aes(months, fill=object3,ymin=value1, ymax=value))+
  geom_line(data = dat_irf_all_3_lines, aes(months,value, colour=object2), size=1)+
  geom_hline(yintercept = c(0), colour = "#737373" )+
  facet_wrap(~ aux2,ncol = 2)+
  labs(y = "Price response", 
       x = "Months",
       title = "SPEI-3, all drought, threshold: -1.5")+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),
        strip.text = element_text(size = 14),legend.position="bottom",legend.title=element_blank(),
        legend.key = element_blank(),
        axis.text=element_text(size=18),
        axis.title=element_text(size=18))+ 
  scale_y_continuous(breaks= c(0,0.05,0.1,0.15,0.2,0.25),labels = scales::percent)+
  scale_colour_manual(values = c("#000000"))+
  scale_fill_manual(values = c("#3182bd","#9ecae1","#deebf7"))+
  #scale_linetype_manual(values = c("dashed","dashed","solid"))+
  scale_x_continuous(breaks = seq(0,30,by=5),limits = c(0, 30))

plot_9

# save figure
setwd(cd_figures)
ggsave("irf_baseline_figure3.pdf",plot=plot_9 , width = 11, height = 8.5) 



#-------------------------------------------------------------------------------------------------
# 4.4. visualization of spei information (Figure A1) ###
#-------------------------------------------------------------------------------------------------  

# prepare data for plot
w1_plot <- w1 %>% dplyr::select('year','month','mean_spei_3_sg','mean_spei_2_sg','mean_spei_4_sg','mean_spei_3_de','mean_spei_2_de','mean_spei_4_de') %>% 
  mutate(date = as.Date(paste(year,month,15, sep = "-"))) %>% 
  gather('mean_spei_3_sg','mean_spei_2_sg','mean_spei_4_sg',
         'mean_spei_3_de','mean_spei_2_de','mean_spei_4_de',
         key = "spei_value",value = "value") %>%
  mutate(group_aux = ifelse(str_detect(spei_value, "spei_3"),"SPEI-3",
                            ifelse(str_detect(spei_value, "spei_2"),"SPEI-2","SPEI-4")),
         region_aux = ifelse(str_detect(spei_value, "sg"),"South Germany","Whole Germany"))



# prepare data for correlations
## set main vegetation period (start: staveg+1, end: endveg-1):
staveg <- 3
endveg <- 11

w1_cor <- w1 %>% dplyr::select("year":"mean_spei_4_de",contains("spei3_y"),contains("spei2_y"),contains("spei4_y")) %>% 
  filter(as.integer(month)>staveg & as.integer(month)<endveg) %>%  # select only months in the main vegetation period 
  mutate(`drought_-1_spei3_y_sd`   = ifelse(`drought_-1_spei3_y_sd`>0,1,0), # we are only interested in the correlation of drought events, therefore 1,0
         `drought_-1.5_spei3_y_sd` = ifelse(`drought_-1.5_spei3_y_sd`>0,1,0),
         `drought_-1_spei3_y_de`   = ifelse(`drought_-1_spei3_y_de`>0,1,0),
         `drought_-1.5_spei3_y_de` = ifelse(`drought_-1.5_spei3_y_de`>0,1,0),
         `drought_-1_spei2_y_sd`   = ifelse(`drought_-1_spei2_y_sd`>0,1,0), 
         `drought_-1.5_spei2_y_sd` = ifelse(`drought_-1.5_spei2_y_sd`>0,1,0),
         `drought_-1_spei2_y_de`   = ifelse(`drought_-1_spei2_y_de`>0,1,0),
         `drought_-1.5_spei2_y_de` = ifelse(`drought_-1.5_spei2_y_de`>0,1,0),
         `drought_-1_spei4_y_sd`   = ifelse(`drought_-1_spei4_y_sd`>0,1,0), 
         `drought_-1.5_spei4_y_sd` = ifelse(`drought_-1.5_spei4_y_sd`>0,1,0),
         `drought_-1_spei4_y_de`   = ifelse(`drought_-1_spei4_y_de`>0,1,0),
         `drought_-1.5_spei4_y_de` = ifelse(`drought_-1.5_spei4_y_de`>0,1,0))

# calculate different correlations         
cor_spei3 <- cor(w1_cor$mean_spei_3_de, w1_cor$mean_spei_3_sg, method = "pearson") # spei-3
cor_spei2 <- cor(w1_cor$mean_spei_2_de, w1_cor$mean_spei_2_sg, method = "pearson") # spei-2
cor_spei4 <- cor(w1_cor$mean_spei_4_de, w1_cor$mean_spei_4_sg, method = "pearson") # spei-4
cor_spei3_severe   <-cor(w1_cor$`drought_-1.5_spei3_y_sd`, w1_cor$`drought_-1.5_spei3_y_de`, method = "pearson") # severe droughts based on spei-3
cor_spei3_moderate <-cor(w1_cor$`drought_-1_spei3_y_sd`, w1_cor$`drought_-1_spei3_y_de`, method = "pearson") # moderate droughts based on spei-3
cor_spei2_severe   <-cor(w1_cor$`drought_-1.5_spei2_y_sd`, w1_cor$`drought_-1.5_spei2_y_de`, method = "pearson") # moderate droughts based on spei-3
cor_spei2_moderate <-cor(w1_cor$`drought_-1_spei2_y_sd`, w1_cor$`drought_-1_spei2_y_de`, method = "pearson") # moderate droughts based on spei-3
cor_spei4_severe   <-cor(w1_cor$`drought_-1.5_spei4_y_sd`, w1_cor$`drought_-1.5_spei4_y_de`, method = "pearson") # moderate droughts based on spei-3
cor_spei4_moderate <-cor(w1_cor$`drought_-1_spei4_y_sd`, w1_cor$`drought_-1_spei4_y_de`, method = "pearson") # moderate droughts based on spei-3

# prepare data frame to add correlations and drought intensity to the figure:
ann_text <- as.data.frame(matrix(nrow = 18, ncol = 4))
colnames(ann_text) <- c("date", "value", "group_aux","text")
ann_text[,1] <- as.Date("2001-01-01") # x-axis position 
ann_text[,2] <- c(rep(c(2.5,2,1.5,1),3),rep(c(-1.65,-1.15),3))  # y-axis position 
ann_text[,3] <- c(rep("SPEI-3",4),rep("SPEI-2",4),rep("SPEI-4",4),rep("SPEI-3",2),rep("SPEI-2",2),rep("SPEI-4",2)) # group
ann_text[1,4] <- paste("Correlations (South Germany, Whole Germany):")
ann_text[2,4] <- paste("SPEI:"   , round(cor_spei3, digits = 2))
ann_text[3,4] <- paste("Severe drought:", round(cor_spei3_severe, digits = 2))
ann_text[4,4] <- paste("Moderate drought:", round(cor_spei3_moderate, digits = 2))
ann_text[5,4] <- paste("Correlations (South Germany, Whole Germany):")
ann_text[6,4] <- paste("SPEI:"   , round(cor_spei2, digits = 2))
ann_text[7,4] <- paste("Severe drought:", round(cor_spei2_severe, digits = 2))
ann_text[8,4] <- paste("Moderate drought:", round(cor_spei2_moderate, digits = 2))
ann_text[9,4] <- paste("Correlations (South Germany, Whole Germany):")
ann_text[10,4] <- paste("SPEI:"   , round(cor_spei4, digits = 2))
ann_text[11,4] <- paste("Severe drought:", round(cor_spei4_severe, digits = 2))
ann_text[12,4] <- paste("Moderate drought:", round(cor_spei4_moderate, digits = 2))
ann_text[13,4] <- paste("Severe droughts")
ann_text[14,4] <- paste("Moderate droughts")
ann_text[15,4] <- paste("Severe droughts")
ann_text[16,4] <- paste("Moderate droughts")
ann_text[17,4] <- paste("Severe droughts")
ann_text[18,4] <- paste("Moderate droughts")

  
## plot 
w1_plot$group_aux  <- factor(w1_plot$group_aux, levels = c("SPEI-3","SPEI-2","SPEI-4")) # order levels  
ann_text$group_aux  <- factor(ann_text$group_aux, levels = c("SPEI-3","SPEI-2","SPEI-4")) # order levels  

plot10 <-
  ggplot() +
  geom_line(data=w1_plot,aes(date, value, color = region_aux))+
  geom_text(data = ann_text,aes(date, value, label =text ),hjust = "inward",size = 4)+
  facet_grid(group_aux ~ .)+
  geom_hline(yintercept = c(-1.5,-1,0), color="#969696",size = 0.4)+
  theme(axis.title.x = element_text( size=16), axis.text.x  = element_text( size=16), 
        axis.title.y = element_text( size=16), axis.text.y  = element_text( size=16),legend.text  = element_text( size=16) ,
        legend.title = element_blank(),title= element_text( size=16),
        legend.position="bottom")+  
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
        panel.background = element_blank(),panel.border = element_rect(colour = "black", fill=NA, size=1),
        strip.background = element_blank(),strip.text = element_text(size=16),
        legend.margin = margin(6, 6, 6, 6))+
  scale_y_continuous(name = "SPEI")+
  scale_x_date(name = "Date",date_breaks = "2 year", date_labels = "%Y", limits = as.Date(c("2001-01-01","2019-04-01")))+
  scale_colour_manual(values=c("#8c510a","#01665e")) # +


plot10

setwd(cd_figures)
ggsave("v1_spei_de_sg_over_time_figureA1.pdf",plot=plot10 , width = 11, height = 8.5) 



