################################################################################
# R Code related to                                                            #
# Drought effects on hay and feed grain prices                                 #
# Sergei Schaub and Robert Finger                                              #                                             
# -----------------------------------------------------------------------------#
# Script: Download and preparation of weather data                             #
#  2019, ETH Zurich                                                           #
# developed by Sergei Schaub                                                   #    
################################################################################


# table of contents:
# 0. general settings
# 1. specification of time period, folder and data structure, etc.
# 2. download and decompress dwd weather data
# 3. prepare and save weather data
# 3.1. shape files
# 3.2. process weather data
# 4. calculation and storing of spei values




################################################################################
#------------------------------- 0. general settings
################################################################################

# install packages
#install.packages(c("curl","esmisc","R.utils","raster","rgdal","sp","SPEI","stringr","tidyverse"))

# load packages
require(curl)
require(esmisc)
require(R.utils)
require(raster)
require(rgdal)
require(sp)
require(SPEI)
require(stringr)
require(tidyverse)



# Remarks:
# a) The shape files were downloaded from:
#    - administrative area: https://gdz.bkg.bund.de/index.php/default/digitale-geodaten/verwaltungsgebiete/verwaltungsgebiete-1-250-000-ebenen-stand-01-01-vg250-ebenen-01-01.html
#    - land cover: https://gdz.bkg.bund.de/index.php/default/open-data/corine-land-cover-10-ha-clc10.html



################################################################################
#------------------------------- 1. specification of time period, folder and data
#-------------------------------    structure, etc.
################################################################################

# define working directory and name of the shape file of german land cover
dir_file_shape_cover <- paste0(cd_input_data,"/corine_landcover/clc10.gk3.shape/clc10/CLC10.shp")

# define working directory and name of the shape file of germany and state boundaries
dir_file_shape_germany <- paste0(cd_input_data,"/vg250_2019-01-01.gk3.shape.ebenen/vg250_ebenen/VG250_LAN.shp")

# define working directory where weather variable folders are located.
cd <- cd_weather_data

# define working directory where weather variables should be stored
cd_save <- cd_processed

# define ftp of the DWD where weather variable folders are located.
ftp <- "ftp://ftp-cdc.dwd.de/climate_environment/CDC/grids_germany/monthly/"

# define .gz file names until the weather variable (we can see the structure of filenames going to the ftp defined before)
gzname <- "grids_germany_monthly_"

# define first and last year and first month of first year and last month of last year:
f_year <- 1991
l_year <- 2019
f_month <- 1
l_month <- 4

a_years <- l_year - f_year # number of year considered

years <- as.data.frame(c(
    rep(f_year, each = (12 + 1 - f_month)),
    rep((f_year + 1):(l_year - 1), each = 12),
    rep(l_year, each = l_month)
  )) # create a vector off all years (times the month in the year)

months <- as.data.frame(c(f_month:12, rep(seq(1:12), (a_years - 1)), 1:l_month)) # create a vector of all months

dates <- bind_cols(years, months) # combine the year and month vectors

colnames(dates) <- c("year", "month") # rename variables

dates <-  dates %>% mutate(month = as.character(ifelse(month < 10, paste0("0", month), paste(month)))) # this step is done in order to merging later data frames

n_dates <- length(dates$year) # length of period in months

# define weather variables that should be downloaded:
wv <- matrix(c("precipitation", "evapo_p"))
n_wv     <- length(wv) # number of weather variables



################################################################################
#------------------------------ 2. download and decompress dwd weather data
################################################################################


if (exists("n_wv")) {  # start run if weather variable is defined
  
  # Note that this steps is only executed when no decompressed file of the first month of the first year exists

  for (s in 1:n_wv) { # first-layer loop: loop over weather variable
    
        v_name   <- wv[s,1] #  weather variable of current loop
        
        # set directory where files are downloaded to: 
        if(v_name=="precipitation"){cd_w <- cd_precipitation} else if (v_name=="evapo_p"){cd_w <- cd_evapo_p}
        setwd(cd_w)
    
        
         
        for(z in 1:n_dates) { # second-layer loop: loop over time
          
          # set ftp where files are downloaded from
          # (note that not all weather variables have on the dwd homepage the same folder structure, therefore 
          # this needs to be defined in this loop. You might need to adjust this step if downloading different variables
          # than precipitation or evapotranspiration):
          
          
          ftp_d <- ifelse(v_name=="evapo_p",paste(ftp, v_name, sep = ""), paste(ftp, v_name,"/", 
                                                                                ifelse(dates[z,2]=="01","01_Jan",
                                                                                       ifelse(dates[z,2]=="02","02_Feb",
                                                                                              ifelse(dates[z,2]=="03","03_Mar",
                                                                                                     ifelse(dates[z,2]=="04","04_Apr",
                                                                                                            ifelse(dates[z,2]=="05","05_May",
                                                                                                                   ifelse(dates[z,2]=="06","06_Jun",
                                                                                                                          ifelse(dates[z,2]=="07","07_Jul",
                                                                                                                                 ifelse(dates[z,2]=="08","08_Aug",
                                                                                                                                        ifelse(dates[z,2]=="09","09_Sep",
                                                                                                                                               ifelse(dates[z,2]=="10","10_Oct",
                                                                                                                                                      ifelse(dates[z,2]=="11","11_Nov","12_Dec"))))))))))),sep = ""))
          
          
          # define file date, i.e. date of weather variable
          file_date <- paste(dates[z,1], dates[z,2], sep = "")  
          
          
          # define file names (two steps)
          file_gz_name <- paste(file_date, ".asc",".gz", sep = "") 
          file_gz_name <- paste(gzname, v_name,"_",file_gz_name, sep = "")  
          
          
          # define directory and name of current source file 
          getfrom <- paste(ftp_d,file_gz_name, sep = "/")
          
          # define directory and name of current produced file 
          getto <-  paste(cd_w,file_gz_name, sep = "/")
          
          # only download file if file is not yet downloaded and decompressed (checks only file of the first month of the first year)
          if(!file.exists(paste0(str_sub(getto,1,-4)))) {
            
            # download:
            download.file(getfrom, destfile = getto) 
            
            # decompress downloaded file
            gunzip(getto,remove=TRUE,overwrite=TRUE) }
          
        } # end of downloading and decompressing
  }}
  
  
################################################################################
#------------------------------ 3. prepare and save weather data
################################################################################


if (exists("n_wv")) { # start run if weather variable is defined
  
  ptm <- proc.time() # time duration of the run
  
  
  #-------------------------------------------------------------------------------------------------
  # 3.1. shape files ###
  #-------------------------------------------------------------------------------------------------
  
  # load shape files
  cover <- readOGR(dir_file_shape_cover) # land cover
  germany <- readOGR(dir_file_shape_germany) # administrative area

  
  # restrict land cover to only:
  ## (211) Non-irrigated arable land,
  ## (231) Pasture, meadows and other permanent grasslands under agricultural use
  ## (242) Complex cultivation patterns
  ## (243) Land principally occupied by agriculture, with significant areas of natural vegetation
  ## (321) Natural grassland
  cover_sub <-cover[which(cover$clc == 211 | cover$clc == 231 | cover$clc == 242 | cover$clc == 243 | cover$clc == 321), ]
  
  # check projections:
  crs(proj4string(cover))   
  crs(proj4string(germany)) 
  
  # list of all states in the map
  list_states <- as.data.frame(germany$GEN)[1:16, ] # needs to be modified, as it includes some twice plus other specific regions
  n_b <- length(list_states) # number of states in shape files
  
  
  #-------------------------------------------------------------------------------------------------
  # 3.2. process weather data ###
  #-------------------------------------------------------------------------------------------------
  
  for (s in 1:n_wv) { # first-layer loop: loop over weather variable
    
    v_name   <- wv[s, 1] # name weather variable of current loop
    
    # define and set directory where weather data is stored: 
    cd <- cd_weather_data
    workdir <- paste(cd,"/", v_name, sep = "")  
     
    
    for (z in 1:n_dates) {
      # second-layer loop: loop over time
      
      # set every time the working directory
      setwd(workdir)
      
      # define file date, i.e. date of weather variable
      file_date <- paste(dates[z, 1], dates[z, 2], sep = "")
      print(file_date) # show the current date
      
      # define file names (two steps)
      file_asc_name <- paste(file_date, ".asc", sep = "")
      file_asc_name <- paste(gzname, v_name, "_", file_asc_name, sep = "")
      
      #read in asc file
      asc1     <- readGDAL(file_asc_name)
      asc1     <- raster(asc1)
      
      # check projection
      # crs(proj4string(asc1)) # check: it shows that no crs is specified
      crs(asc1) <- CRS("+init=epsg:31467") # therefore add crs http://spatialreference.org/ref/epsg/dhdn-gauss-kruger-zone-3/
      # crs(proj4string(asc1)) # check
      
      
      # third-layer loop: loop over states
      for (b in 1:n_b) { # only keep weather information of agricultural area
        if (b == 1) { # this step needs only to be tone for the first state 
          
          # mask the data, i.e. cut out of the data raster only the grids that covered by specified land cover:
          r_cut1 <- mask(asc1, cover_sub)
        }
        
        
        # only keep weather information of a specific state
        state_current <- as.character(germany$GEN[b]) # define state of current loop
        print(state_current) # show the current state
        germany_state <- germany[germany$GEN == state_current, ] # re-shape shape file to only the current state
        r_cut2 <- mask(r_cut1, germany_state) # mask the data, i.e. cut out of the data raster only the grids that are in the current state
        
        # check if everything worked:
        #plot(r_cut2)
        #plot(germany, add=TRUE)
        
        
        # prepare data for and save csv file
        f_name_current <- paste(v_name, "monthly", file_date, sep = "_") # create file name (includes information about weather variable, time resolution and date)
        v_name_current <- paste(state_current, v_name, "monthly", file_date, sep = "_") # create coloum name (includes information about weather variable, time resolution, date state)
        
        if (b == 1) {
          # for the first variable of the file, i.e. first state, create a data frame that includes next to weather information also longitude and latitude
          long <- as.data.frame(coordinates(r_cut2)[, 1])   # extract longitude from raster
          lat  <- as.data.frame(coordinates(r_cut2)[, 2])   # extract latitude from raster
        }  
        
        d_wv <- as.data.frame(r_cut2@data@values)          # extract weather variable from raster
        d_aux2 <- bind_cols(long, lat, d_wv) # combine data
        colnames(d_aux2) <- c("lon", "lat", paste(v_name_current)) # rename date
        
        if (b == 1) {
          # if the first variable of the file, start a new dataset, if not add to existing dataset
          d1 <- d_aux2
        } else {
          d1 <- bind_cols(d1, (d_aux2 %>% dplyr::select(c(paste(v_name_current)))))
        }
        
        if (b == n_b) {
          # if the last state save the data frame as a csv and remove large and not any more needed objects from environment
          
          setwd(cd_save) # set directory
          final_file_name <- paste0("all_ag_area_", f_name_current, ".csv") # name of file
          d1 %>% write.csv(final_file_name, row.names = F) # write csv file
          rm(d1, d_aux2, r_cut1, r_cut2) # remove objects from environment
        }
        
      } # end loop over states
      
      
      
    } # end loop over time
  } # end loop over weather variables
  proc.time() - ptm # stop timing of the loop
  } # end of raster processing



################################################################################
#------------------------------ 4. calculation and storing of spei values
################################################################################


# define working directory where weather variables should be stored
cd_save <- cd_processed
setwd(cd_save) # set directory

# create list of all weather files for i) evapotranspiration and ii) precipitation
evapo_name <- list.files(pattern = "evapo_p")
preci_name <- list.files(pattern = "precipitation")

# define number of loops per weather variable
length_evapo <- length(evapo_name)
length_preci <- length(preci_name)
# show(length_evapo)
# show(length_preci)

number_states <- 16 # set number of states in germany

#-------------------------------------------------------------------------------------------------
# 4.1. calculation of spei state and per grid ###
#------------------------------------------------------------------------------------------------- 


for(s in 1:number_states) { # first-layer loop: loop over states
  for(i in 1:2) { # second-layer loop: loop over weather variable
    
    # set number of loops of current weather variable and name it:
    if(i==1){ length_wv <- length_evapo 
    name_wv <- "evapo_p"} else {
      length_wv <- length_preci
      name_wv <- "precipitation"}
    
    for(t in 1:length_wv) { # third-layer loop: loop over time
      
      # define current file name
      if(i==1){cur_file <- evapo_name[t]}
      if(i==2){cur_file <- preci_name[t]}
      
      d1 <-read.csv(cur_file) # load current file
      
      name_state <- colnames(d1)[s+2] # get current state name (plus 2 as the first two columns are longitude and latitude)
      name_state2 <- sub("\\_.*", "", name_state) # isolate the state name
      name_date <- str_sub(name_state, start = -6) # get current date
      name_col <- paste(name_wv,sep = "_") # set column name
      name_file <- paste(name_state2,"all_agr_spei.csv",sep = "_") # set file name
      
      if(t==1){ d2 <- d1[,1:2] } # for the first run extract coordinates
      d3 <- d2
      d3$date <- name_date # add date
      colnames(d1)[s+2] <- name_col
      d3 <- bind_cols(d3,d1[s+2])
      
      if(t==1){ d4 <- d3} else { d4 <- bind_rows(d4,d3)}
      
      # if last loop of a weather variable create a new data frame
      if(i==1 & t==length_wv){ e1 <- d4}
      if(i==2 & t==length_wv){ p1 <- d4}
      print(paste0(name_state2," (",s,"): ",name_wv," ",t,"/",length_wv)) # show prgress of the loop
    }
    
  }
  
  # merge evapotranspiration and precipitation, calculate water balance and obtain variables for month and year
  d5 <- bind_cols(e1,p1[4]) 
  d5 <- d5 %>% mutate(location_id = paste(lon,lat,sep = "_"),
                      bal = precipitation-evapo_p/10,
                      month = as.integer(str_sub(date,-2,-1)),
                      year = as.integer(str_sub(date,-6,-3)))
  
  
  # get an idea about the properties of water balance variable:
  # summary(d5[7]) 
  
  
  # create for each location a variable of water balance: 
  d6 <- d5 %>% filter(!is.na(bal)) %>% dplyr::select(c(year,month,bal,location_id)) %>% tidyr::spread(location_id,bal)
  
  # compute spei (using a loop)
  spei_lengths <- c(3,2,4) # define spei lengths : 3,2,4
  n_spei1 <- length(spei_lengths) # number of different spei lengths
  n_spei2 <- (ncol(d6)-2) # number of cells
  
  for(o in 1:n_spei1) { # loop over spei lengths
    
    for(l in 1:n_spei2) { # loop over cells
      
            d6t <- ts(d6[,(l+2)-1]) # transform data into a time series
            spei3_m <- spei(d6t, spei_lengths[o]) # compute spei
      
            
                      if (l==1) { # if first month of the first weather variable, start new data frame, if not add to existing data frame
      
                        s1 <- d6[,1:(l+2)]# first get year and month information as well as name of column
                        s1[,(l+2)] <- spei3_m$fitted} else { # override water balance information with spei information
                          s1 <- bind_cols(s1,(as.data.frame(d6[,c(1,(l+2))]) %>% select(contains("_"))))
                          s1[,(l+2)] <- spei3_m$fitted}
      
            print(paste0(name_state2," (",s,"): ","spei-",spei_lengths[o],"; run ",l,"/",n_spei2)) # show current process of the loop
      
      
      
      
    } # end spei computing loop - of one spei length 
    
    # compute mean spei of current spei length and for current state
    
    s1$spei.mean <- rowMeans(s1[c(3:(length(s1)))])
    if(o==1) { s2 <- s1 %>% dplyr::select(year, month, spei.mean) } else { # if the spei-length loop is the first round create a new dataset, otherwise add to existing
      s2 <- s2 %>% bind_cols((s1 %>% dplyr::select(spei.mean))) } 
    
    colnames(s2)[length(s2)] <- paste("mean_spei",o,sep="_") # name columns
    
    
  } # end spei computing loop
  
  
  s2 %>% write.csv(name_file, row.names = F) # write csv file (for each state)
  rm(s1,s2,d6,d6t) # remove objects from environment
}



#-------------------------------------------------------------------------------------------------
# 4.2. calculation of spei across i) south germany and ii) whole germany ###
#------------------------------------------------------------------------------------------------- 

# define working directory where weather variables should be stored
cd_save <- cd_processed
setwd(cd_save) # set directory

spei_name <- list.files(pattern = "all_agr_spei") # create list of all spei files 

length_spei <- length(spei_name) # number of spei files = number of loops

for(z in 1:length_spei) { # first-layer loop: loop over states
  
  csv_file <- spei_name[z]
  name_state_csv <- sub("\\_.*", "", csv_file) # isolate current state name
  
  a1 <-read.csv(paste(csv_file), header=T,sep=",")  %>% mutate(state = name_state_csv) # load data
  
  if(z==1){d1 <- a1} else {d1 <- bind_rows(d1,a1)} # create new or add to dataset
} # end of loop

colnames(d1) <- c("year","month","mean_spei_3","mean_spei_2","mean_spei_4","state") # rename spei values



# we need to obtain the weights, i.e. the grids amounts of agricultural area per state relative to the entire agricultural area in germany. 
# create data frame with grids per state
number_states <- 16 # number of states = number of loops
d1aux <-read.csv("all_ag_area_evapo_p_monthly_201904.csv") # derive from "all_ag_area_evapo_p_monthly_201904.csv" the number of grids

for(s in 1:number_states) { # first-layer loop: loop over states
  
    name_state <- colnames(d1aux)[s+2] # get current state name (plus 2 as the first two columns are longitude and latitude)
    name_state2 <- sub("\\_.*", "", name_state) # isolate the state name
    if (name_state2=="Sachsen") {name_state2 <- paste0(name_state2,"_")} # only needed for state=Sachsen in order to not identify other states 
    d2aux <- d1aux %>% dplyr::select(starts_with(name_state2))
    colnames(d2aux) <- "ref"
    d2aux <- d2aux %>% filter(!is.na(ref))
    weight <- length(d2aux$ref)
    if (s==1) {d3aux<- as.data.frame(matrix(nrow = number_states, ncol = 2))
    colnames(d3aux) <- c("state","weight")}
    if (name_state2=="Sachsen_") {name_state2 <- "Sachsen"} # only needed for state=Sachsen in order to match later
    d3aux[s,1] <- name_state2 # name of current state
    d3aux[s,2] <- weight # weight, i.e. number of grid sells, of current state
  }




# extract weight per state:
weight_SH <- (d3aux %>% filter(state=="Schleswig.Holstein"))[1,2]
weight_HA <- (d3aux %>% filter(state=="Hamburg"))[1,2]
weight_NS <- (d3aux %>% filter(state=="Niedersachsen"))[1,2]
weight_Bremen <- (d3aux %>% filter(state=="Bremen"))[1,2]
weight_NW <- (d3aux %>% filter(state=="Nordrhein.Westfalen"))[1,2]
weight_HE <- (d3aux %>% filter(state=="Hessen"))[1,2]
weight_RP <- (d3aux %>% filter(state=="Rheinland.Pfalz"))[1,2]
weight_BW <- (d3aux %>% filter(state=="Baden.W.rttemberg"))[1,2]
weight_BA <- (d3aux %>% filter(state=="Bayern"))[1,2]
weight_SAA <- (d3aux %>% filter(state=="Saarland"))[1,2]
weight_Berlin <- (d3aux %>% filter(state=="Berlin"))[1,2]
weight_BR <- (d3aux %>% filter(state=="Brandenburg"))[1,2]
weight_MV <- (d3aux %>% filter(state=="Mecklenburg.Vorpommern"))[1,2]
weight_SAC <- (d3aux %>% filter(state=="Sachsen"))[1,2]
weight_SA <- (d3aux %>% filter(state=="Sachsen.Anhalt"))[1,2]
weight_TH <- (d3aux %>% filter(state=="Th.ringen"))[1,2]

# get the sum of grids per region 
sum_de <- weight_SH + weight_HA + weight_NS + weight_Bremen + weight_NW + weight_HE + weight_RP + weight_BW + weight_BA + 
  weight_SAA + weight_Berlin + weight_BR + weight_MV + weight_SAC + weight_SA + weight_TH # whole germany
sum_sg <- weight_BA + weight_BW # south germany

# get mean spei-3 values
d1spei3 <- d1 %>% 
  mutate(date = as.Date(paste(year,month,15, sep = "-"))) %>% 
  dplyr::select(c("year","month","mean_spei_3","state")) %>% 
  tidyr::spread(state,mean_spei_3) %>% 
  mutate(mean_spei_3_de = 
           Baden.W.rttemberg     * weight_BW     / sum_de +
           Bayern                 * weight_BA     / sum_de +
           Berlin                 * weight_Berlin / sum_de +                 
           Brandenburg            * weight_BR     / sum_de + 
           Bremen                 * weight_Bremen / sum_de + 
           Hamburg                * weight_HA     / sum_de + 
           Hessen                 * weight_HE     / sum_de + 
           Mecklenburg.Vorpommern * weight_MV     / sum_de + 
           Niedersachsen          * weight_NS     / sum_de + 
           Nordrhein.Westfalen    * weight_NW     / sum_de + 
           Rheinland.Pfalz        * weight_RP     / sum_de + 
           Saarland               * weight_SAA    / sum_de +
           Sachsen                * weight_SAC    / sum_de +
           Sachsen.Anhalt         * weight_SA     / sum_de +
           Schleswig.Holstein     * weight_SH     / sum_de +
           Th.ringen             * weight_TH     / sum_de, 
           
         mean_spei_3_sg = 
           Baden.W.rttemberg     * weight_BW     / sum_sg +
           Bayern                 * weight_BA     / sum_sg) %>% 
  dplyr::select(year,month,mean_spei_3_de,mean_spei_3_sg)


# get mean spei-2 values
d1spei2 <- d1 %>% 
  mutate(date = as.Date(paste(year,month,15, sep = "-"))) %>% 
  dplyr::select(c("year","month","mean_spei_2","state")) %>% 
  tidyr::spread(state,mean_spei_2) %>% 
  mutate(mean_spei_2_de = 
           Baden.W.rttemberg     * weight_BW     / sum_de +
           Bayern                 * weight_BA     / sum_de +
           Berlin                 * weight_Berlin / sum_de +                 
           Brandenburg            * weight_BR     / sum_de + 
           Bremen                 * weight_Bremen / sum_de + 
           Hamburg                * weight_HA     / sum_de + 
           Hessen                 * weight_HE     / sum_de + 
           Mecklenburg.Vorpommern * weight_MV     / sum_de + 
           Niedersachsen          * weight_NS     / sum_de + 
           Nordrhein.Westfalen    * weight_NW     / sum_de + 
           Rheinland.Pfalz        * weight_RP     / sum_de + 
           Saarland               * weight_SAA    / sum_de +
           Sachsen                * weight_SAC    / sum_de +
           Sachsen.Anhalt         * weight_SA     / sum_de +
           Schleswig.Holstein     * weight_SH     / sum_de +
           Th.ringen             * weight_TH     / sum_de, 
         
         mean_spei_2_sg = 
           Baden.W.rttemberg     * weight_BW     / sum_sg +
           Bayern                 * weight_BA     / sum_sg) %>% 
  dplyr::select(mean_spei_2_de,mean_spei_2_sg)
  

# get mean spei-4 values
d1spei4 <- d1 %>% 
  mutate(date = as.Date(paste(year,month,15, sep = "-"))) %>% 
  dplyr::select(c("year","month","mean_spei_4","state")) %>% 
  tidyr::spread(state,mean_spei_4) %>% 
  mutate(mean_spei_4_de = 
           Baden.W.rttemberg     * weight_BW     / sum_de +
           Bayern                 * weight_BA     / sum_de +
           Berlin                 * weight_Berlin / sum_de +                 
           Brandenburg            * weight_BR     / sum_de + 
           Bremen                 * weight_Bremen / sum_de + 
           Hamburg                * weight_HA     / sum_de + 
           Hessen                 * weight_HE     / sum_de + 
           Mecklenburg.Vorpommern * weight_MV     / sum_de + 
           Niedersachsen          * weight_NS     / sum_de + 
           Nordrhein.Westfalen    * weight_NW     / sum_de + 
           Rheinland.Pfalz        * weight_RP     / sum_de + 
           Saarland               * weight_SAA    / sum_de +
           Sachsen                * weight_SAC    / sum_de +
           Sachsen.Anhalt         * weight_SA     / sum_de +
           Schleswig.Holstein     * weight_SH     / sum_de +
           Th.ringen             * weight_TH     / sum_de, 
         
         mean_spei_4_sg = 
           Baden.W.rttemberg     * weight_BW     / sum_sg +
           Bayern                 * weight_BA     / sum_sg) %>% 
  dplyr::select(mean_spei_4_de,mean_spei_4_sg)
  

d1spei <- bind_cols(d1spei3,d1spei2,d1spei4)


# save result:
setwd(cd_processed)
d1spei %>% write.csv('spei_data_SG_DE.csv', row.names = F)

